==> haskell-bindings-dsl-1.0.25-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bindings-dsl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bindings-DSL
version:              1.0.25
visibility:           public
id:                   bindings-DSL-1.0.25-51D7hYSqriS1WqHCSJdMor
key:                  bindings-DSL-1.0.25-51D7hYSqriS1WqHCSJdMor
license:              BSD-3-Clause
maintainer:           John Wiegley <johnw@newartisans.com>
author:               Maurício C. Antunes
stability:            Stable API, well tested, portable, used in commercial code.
homepage:             https://github.com/jwiegley/bindings-dsl/wiki
synopsis:             FFI domain specific language, on top of hsc2hs.
description:
    This is a set of macros to be used when writing Haskell FFI.
    They were designed to be able to fully describe C interfaces,
    so that hsc2hs can extract from them all Haskell code needed to
    mimic such interfaces. All Haskell names used are automatically
    derived from C names, structures are mapped to Haskell instances
    of Storable, and there are also macros you can use with C code
    to help write bindings to inline functions or macro functions.
    Documentation is available at package homepage:

    <https://github.com/jwiegley/bindings-dsl/wiki>

    The extra module Bindings.Utilities will contain tools that may
    be convenient when working with FFI.

category:             FFI
abi:                  d16add22f6715b9f0b8b3bfe789952aa
exposed:              True
exposed-modules:      Bindings.Utilities
import-dirs:          /usr/lib/ghc-9.0.2/site-local/bindings-DSL-1.0.25
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bindings-DSL-1.0.25
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bindings-dsl
hs-libraries:         HSbindings-DSL-1.0.25-51D7hYSqriS1WqHCSJdMor
include-dirs:         /usr/lib/ghc-9.0.2/site-local/bindings-DSL-1.0.25/include
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-bindings-dsl/html/bindings-DSL.haddock

haddock-html:         /usr/share/doc/haskell-bindings-dsl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bindings-dsl-1.0.25-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bindings-dsl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bindings-DSL
version:              1.0.25
visibility:           public
id:                   bindings-DSL-1.0.25-JOzAkp7j2MdCTSUp0EnJT8
key:                  bindings-DSL-1.0.25-JOzAkp7j2MdCTSUp0EnJT8
license:              BSD-3-Clause
maintainer:           John Wiegley <johnw@newartisans.com>
author:               Maurício C. Antunes
stability:            Stable API, well tested, portable, used in commercial code.
homepage:             https://github.com/jwiegley/bindings-dsl/wiki
synopsis:             FFI domain specific language, on top of hsc2hs.
description:
    This is a set of macros to be used when writing Haskell FFI.
    They were designed to be able to fully describe C interfaces,
    so that hsc2hs can extract from them all Haskell code needed to
    mimic such interfaces. All Haskell names used are automatically
    derived from C names, structures are mapped to Haskell instances
    of Storable, and there are also macros you can use with C code
    to help write bindings to inline functions or macro functions.
    Documentation is available at package homepage:

    <https://github.com/jwiegley/bindings-dsl/wiki>

    The extra module Bindings.Utilities will contain tools that may
    be convenient when working with FFI.

category:             FFI
abi:                  bf96df441d8e2b7ab1a6f2c160cb4992
exposed:              True
exposed-modules:      Bindings.Utilities
import-dirs:          /usr/lib/ghc-9.2.8/site-local/bindings-DSL-1.0.25
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bindings-DSL-1.0.25
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bindings-dsl
hs-libraries:         HSbindings-DSL-1.0.25-JOzAkp7j2MdCTSUp0EnJT8
include-dirs:         /usr/lib/ghc-9.2.8/site-local/bindings-DSL-1.0.25/include
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-bindings-dsl/html/bindings-DSL.haddock

haddock-html:         /usr/share/doc/haskell-bindings-dsl/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
